=============================
face_recognition_service
=============================


.. image:: https://img.shields.io/pypi/v/face_recognition_service.svg
        :target: https://pypi.python.org/pypi/face_recognition_service

.. image:: https://img.shields.io/travis/kedpter/face_recognition_service.svg
        :target: https://travis-ci.org/kedpter/face_recognition_service

.. image:: https://readthedocs.org/projects/face-recognition-service/badge/?version=latest
        :target: https://face-recognition-service.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




face recognition api service


* Free software: MIT license
* Documentation: https://face-recognition-service.readthedocs.io.


Features
--------

* TODO
